<?php
/**
 * VW Hospital Lite Theme Customizer
 *
 * @package VW Hospital Lite
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function vw_hospital_lite_custom_controls() {

    load_template( trailingslashit( get_template_directory() ) . '/inc/custom-controls.php' );
}
add_action( 'customize_register', 'vw_hospital_lite_custom_controls' );

function vw_hospital_lite_customize_register( $wp_customize ) {

	load_template( trailingslashit( get_template_directory() ) . 'inc/customize-homepage/class-customize-homepage.php' );

	//add home page setting pannel
	$wp_customize->add_panel( 'vw_hospital_lite_panel_id', array(
	    'priority' => 10,
	    'capability' => 'edit_theme_options',
	    'theme_supports' => '',
	    'title' => __( 'VW Settings', 'vw-hospital-lite' ),
	    'description' => __( 'Description of what this panel does.', 'vw-hospital-lite' ),
	) );

	//Layouts
	$wp_customize->add_section( 'vw_hospital_lite_left_right', array(
    	'title'      => __( 'General Settings', 'vw-hospital-lite' ),
		'priority'   => 30,
		'panel' => 'vw_hospital_lite_panel_id'
	) );

	$wp_customize->add_setting('vw_hospital_lite_width_option',array(
        'default' => __('Full Width','vw-hospital-lite'),
        'sanitize_callback' => 'vw_hospital_lite_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Hospital_Lite_Image_Radio_Control($wp_customize, 'vw_hospital_lite_width_option', array(
        'type' => 'select',
        'label' => __('Width Layouts','vw-hospital-lite'),
        'description' => __('Here you can change the width layout of Website.','vw-hospital-lite'),
        'section' => 'vw_hospital_lite_left_right',
        'choices' => array(
            'Full Width' => get_template_directory_uri().'/images/full-width.png',
            'Wide Width' => get_template_directory_uri().'/images/wide-width.png',
            'Boxed' => get_template_directory_uri().'/images/boxed-width.png',
    ))));

	// Add Settings and Controls for Layout
	$wp_customize->add_setting('vw_hospital_lite_theme_options',array(
        'default' => __('Right Sidebar','vw-hospital-lite'),
        'sanitize_callback' => 'vw_hospital_lite_sanitize_choices'	        
	) );
	$wp_customize->add_control('vw_hospital_lite_theme_options', array(
        'type' => 'select',
        'label' => __('Post Sidebar Layout','vw-hospital-lite'),
        'description' => __('Here you can change the sidebar layout for posts. ','vw-hospital-lite'),
        'section' => 'vw_hospital_lite_left_right',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','vw-hospital-lite'),
            'Right Sidebar' => __('Right Sidebar','vw-hospital-lite'),
            'One Column' => __('One Column','vw-hospital-lite'),
            'Three Columns' => __('Three Columns','vw-hospital-lite'),
            'Four Columns' => __('Four Columns','vw-hospital-lite'),
            'Grid Layout' => __('Grid Layout','vw-hospital-lite')
        ),
	));

	$wp_customize->add_setting('vw_hospital_lite_page_layout',array(
        'default' => __('One Column','vw-hospital-lite'),
        'sanitize_callback' => 'vw_hospital_lite_sanitize_choices'
	));
	$wp_customize->add_control('vw_hospital_lite_page_layout',array(
        'type' => 'select',
        'label' => __('Page Sidebar Layout','vw-hospital-lite'),
        'description' => __('Here you can change the sidebar layout for pages. ','vw-hospital-lite'),
        'section' => 'vw_hospital_lite_left_right',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','vw-hospital-lite'),
            'Right Sidebar' => __('Right Sidebar','vw-hospital-lite'),
            'One Column' => __('One Column','vw-hospital-lite')
        ),
	) );

	//Pre-Loader
	$wp_customize->add_setting( 'vw_hospital_lite_loader_enable',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_hospital_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Hospital_Lite_Toggle_Switch_Custom_control( $wp_customize, 'vw_hospital_lite_loader_enable',array(
        'label' => esc_html__( 'Pre-Loader','vw-hospital-lite' ),
        'section' => 'vw_hospital_lite_left_right'
    )));

    $wp_customize->add_setting('vw_hospital_lite_loader_icon',array(
        'default' => __('Two Way','vw-hospital-lite'),
        'sanitize_callback' => 'vw_hospital_lite_sanitize_choices'
	));
	$wp_customize->add_control('vw_hospital_lite_loader_icon',array(
        'type' => 'select',
        'label' => __('Pre-Loader Type','vw-hospital-lite'),
        'section' => 'vw_hospital_lite_left_right',
        'choices' => array(
            'Two Way' => __('Two Way','vw-hospital-lite'),
            'Dots' => __('Dots','vw-hospital-lite'),
            'Rotate' => __('Rotate','vw-hospital-lite')
        ),
	) );

	//Topbar
	$wp_customize->add_section('vw_hospital_lite_top',array(
        'title' => __('Contact Us','vw-hospital-lite'),
        'description'   => __('This section is used to display address and contact','vw-hospital-lite'),
        'panel' => 'vw_hospital_lite_panel_id',
    ));

    $wp_customize->add_setting( 'vw_hospital_lite_topbar_hide_show',array(
    	'default' => 1,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'vw_hospital_lite_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Hospital_Lite_Toggle_Switch_Custom_control( $wp_customize, 'vw_hospital_lite_topbar_hide_show',array(
      	'label' => esc_html__( 'Show / Hide Topbar','vw-hospital-lite' ),
      	'section' => 'vw_hospital_lite_top'
    )));

    //Sticky Header
	$wp_customize->add_setting( 'vw_hospital_lite_sticky_header',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_hospital_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Hospital_Lite_Toggle_Switch_Custom_control( $wp_customize, 'vw_hospital_lite_sticky_header',array(
        'label' => esc_html__( 'Sticky Header','vw-hospital-lite' ),
        'section' => 'vw_hospital_lite_top'
    )));

    $wp_customize->add_setting('vw_hospital_lite_contact_call',array(
        'default'   => '',
        'sanitize_callback' => 'sanitize_text_field',
    ));
    
    $wp_customize->add_control('vw_hospital_lite_contact_call',array(
        'label' => __('Contact No ','vw-hospital-lite'),
        'section' => 'vw_hospital_lite_top',
        'setting'   => 'vw_hospital_lite_contact_call',
        'type'  => 'text'
    ) );

    $wp_customize->add_setting('vw_hospital_lite_contact_email',array(
        'default'   => '',
        'sanitize_callback' => 'sanitize_text_field',
    ));
    
    $wp_customize->add_control('vw_hospital_lite_contact_email',array(
        'label' => __('Email Address','vw-hospital-lite'),
        'section' => 'vw_hospital_lite_top',
        'setting'   => 'vw_hospital_lite_contact_email',
        'type'  => 'text'
    ) );

    $wp_customize->add_setting('vw_hospital_lite_appointment1',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_hospital_lite_appointment1',array(
		'label'	=> __('Add Appointment text','vw-hospital-lite'),
		'section'	=> 'vw_hospital_lite_top',
		'type'	=> 'text'
	));

	$wp_customize->add_setting('vw_hospital_lite_appointment',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));	
	$wp_customize->add_control('vw_hospital_lite_appointment',array(
		'label'	=> __('Add Appointment Link','vw-hospital-lite'),
		'section'	=> 'vw_hospital_lite_top',
		'setting'	=> 'vw_hospital_lite_appointment',
		'type'	=> 'url'
	));

	 $wp_customize->add_setting('vw_hospital_lite_timing1',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_hospital_lite_timing1',array(
		'label'	=> __('Add Timing text','vw-hospital-lite'),
		'section'	=> 'vw_hospital_lite_top',
		'type'	=> 'text'
	));

	$wp_customize->add_setting('vw_hospital_lite_timing',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));	
	$wp_customize->add_control('vw_hospital_lite_timing',array(
		'label'	=> __('Add Timing Url','vw-hospital-lite'),
		'section'	=> 'vw_hospital_lite_top',
		'setting'	=> 'vw_hospital_lite_timing',
		'type'	=> 'url'
	));

	$wp_customize->add_setting( 'vw_hospital_lite_searchbox',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_hospital_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Hospital_Lite_Toggle_Switch_Custom_control( $wp_customize, 'vw_hospital_lite_searchbox',array(
        'label' => esc_html__( 'Search Box','vw-hospital-lite' ),
        'section' => 'vw_hospital_lite_top'
    )));

	//home page slider
    $wp_customize->add_section( 'vw_hospital_lite_slidersettings' , array(
      'title'      => __( 'Slider Settings', 'vw-hospital-lite' ),
      'priority'   => null,
      'panel' => 'vw_hospital_lite_panel_id'
    ) );

    $wp_customize->add_setting( 'vw_hospital_lite_slider_hide_show',
       array(
          'default' => 1,
          'transport' => 'refresh',
          'sanitize_callback' => 'vw_hospital_lite_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Hospital_Lite_Toggle_Switch_Custom_control( $wp_customize, 'vw_hospital_lite_slider_hide_show',
       array(
          'label' => esc_html__( 'Show / Hide Slider','vw-hospital-lite' ),
          'section' => 'vw_hospital_lite_slidersettings'
    )));

    for ( $count = 1; $count <= 4; $count++ ) {

    // Add color scheme setting and control.
    $wp_customize->add_setting( 'vw_hospital_lite_slider_page' . $count, array(
      'default'           => '',
      'sanitize_callback' => 'vw_hospital_lite_sanitize_dropdown_pages'
    ) );
    $wp_customize->add_control( 'vw_hospital_lite_slider_page' . $count, array(
      'label'    => __( 'Select Slide Image Page', 'vw-hospital-lite' ),
      'description' => __('Slider image size (1500 x 765)','vw-hospital-lite'),
      'section'  => 'vw_hospital_lite_slidersettings',
      'type'     => 'dropdown-pages'
    ) );
    
    }

    //content layout
	$wp_customize->add_setting('vw_hospital_lite_slider_content_option',array(
        'default' => __('Center','vw-hospital-lite'),
        'sanitize_callback' => 'vw_hospital_lite_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Hospital_Lite_Image_Radio_Control($wp_customize, 'vw_hospital_lite_slider_content_option', array(
        'type' => 'select',
        'label' => __('Slider Content Layouts','vw-hospital-lite'),
        'section' => 'vw_hospital_lite_slidersettings',
        'choices' => array(
            'Left' => get_template_directory_uri().'/images/slider-content1.png',
            'Center' => get_template_directory_uri().'/images/slider-content2.png',
            'Right' => get_template_directory_uri().'/images/slider-content3.png',
    ))));

    //Slider excerpt
	$wp_customize->add_setting( 'vw_hospital_lite_slider_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'absint',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'vw_hospital_lite_slider_excerpt_number', array(
		'label'       => esc_html__( 'Slider Excerpt length','vw-hospital-lite' ),
		'section'     => 'vw_hospital_lite_slidersettings',
		'type'        => 'range',
		'settings'    => 'vw_hospital_lite_slider_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	//Opacity
	$wp_customize->add_setting('vw_hospital_lite_slider_opacity_color',array(
      'default'              => 0.5,
      'sanitize_callback' => 'vw_hospital_lite_sanitize_choices'
	));

	$wp_customize->add_control( 'vw_hospital_lite_slider_opacity_color', array(
	'label'       => esc_html__( 'Slider Image Opacity','vw-hospital-lite' ),
	'section'     => 'vw_hospital_lite_slidersettings',
	'type'        => 'select',
	'settings'    => 'vw_hospital_lite_slider_opacity_color',
	'choices' => array(
      '0' =>  esc_attr('0','vw-hospital-lite'),
      '0.1' =>  esc_attr('0.1','vw-hospital-lite'),
      '0.2' =>  esc_attr('0.2','vw-hospital-lite'),
      '0.3' =>  esc_attr('0.3','vw-hospital-lite'),
      '0.4' =>  esc_attr('0.4','vw-hospital-lite'),
      '0.5' =>  esc_attr('0.5','vw-hospital-lite'),
      '0.6' =>  esc_attr('0.6','vw-hospital-lite'),
      '0.7' =>  esc_attr('0.7','vw-hospital-lite'),
      '0.8' =>  esc_attr('0.8','vw-hospital-lite'),
      '0.9' =>  esc_attr('0.9','vw-hospital-lite')
	),
	));

	//OUR services
	$wp_customize->add_section('vw_hospital_lite_our_services',array(
		'title'	=> __('Our Services','vw-hospital-lite'),
		'description'=> __('This section will appear below the slider.','vw-hospital-lite'),
		'panel' => 'vw_hospital_lite_panel_id',
	));	

	$wp_customize->add_setting('vw_hospital_lite_sec1_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	
	$wp_customize->add_control('vw_hospital_lite_sec1_title',array(
		'label'	=> __('Section Title','vw-hospital-lite'),
		'section'=> 'vw_hospital_lite_our_services',
		'setting'=> 'vw_hospital_lite_sec1_title',
		'type'=> 'text'
	));	

	for ( $count = 0; $count <= 3; $count++ ) {

		$wp_customize->add_setting( 'vw_hospital_lite_servicesettings' . $count, array(
			'default'           => '',
			'sanitize_callback' => 'vw_hospital_lite_sanitize_dropdown_pages'
		));
		$wp_customize->add_control( 'vw_hospital_lite_servicesettings' . $count, array(
			'label'    => __( 'Select Service Page', 'vw-hospital-lite' ),
			'section'  => 'vw_hospital_lite_our_services',
			'type'     => 'dropdown-pages'
		));
	}

	$wp_customize->add_setting( 'vw_hospital_lite_service_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'absint',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'vw_hospital_lite_service_excerpt_number', array(
		'label'       => esc_html__( 'Services Excerpt length','vw-hospital-lite' ),
		'section'     => 'vw_hospital_lite_our_services',
		'type'        => 'range',
		'settings'    => 'vw_hospital_lite_service_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	//Blog Post
	$wp_customize->add_section('vw_hospital_lite_blog_post',array(
		'title'	=> __('Blog Post Settings','vw-hospital-lite'),
		'panel' => 'vw_hospital_lite_panel_id',
	));	

	$wp_customize->add_setting( 'vw_hospital_lite_toggle_postdate',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_hospital_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Hospital_Lite_Toggle_Switch_Custom_control( $wp_customize, 'vw_hospital_lite_toggle_postdate',array(
        'label' => esc_html__( 'Post Date','vw-hospital-lite' ),
        'section' => 'vw_hospital_lite_blog_post'
    )));

    $wp_customize->add_setting( 'vw_hospital_lite_toggle_author',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_hospital_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Hospital_Lite_Toggle_Switch_Custom_control( $wp_customize, 'vw_hospital_lite_toggle_author',array(
		'label' => esc_html__( 'Author','vw-hospital-lite' ),
		'section' => 'vw_hospital_lite_blog_post'
    )));

    $wp_customize->add_setting( 'vw_hospital_lite_toggle_comments',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_hospital_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Hospital_Lite_Toggle_Switch_Custom_control( $wp_customize, 'vw_hospital_lite_toggle_comments',array(
		'label' => esc_html__( 'Comments','vw-hospital-lite' ),
		'section' => 'vw_hospital_lite_blog_post'
    )));

    $wp_customize->add_setting( 'vw_hospital_lite_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'absint',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'vw_hospital_lite_excerpt_number', array(
		'label'       => esc_html__( 'Excerpt length','vw-hospital-lite' ),
		'section'     => 'vw_hospital_lite_blog_post',
		'type'        => 'range',
		'settings'    => 'vw_hospital_lite_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	//Content Creation
	$wp_customize->add_section( 'vw_hospital_lite_content_section' , array(
    	'title' => __( 'Customize Home Page Settings', 'vw-hospital-lite' ),
		'priority' => null,
		'panel' => 'vw_hospital_lite_panel_id'
	) );

	$wp_customize->add_setting('vw_hospital_lite_content_creation_main_control', array(
		'sanitize_callback' => 'esc_html',
	) );

	$homepage= get_option( 'page_on_front' );

	$wp_customize->add_control(	new VW_Hospital_Lite_Content_Creation( $wp_customize, 'vw_hospital_lite_content_creation_main_control', array(
		'options' => array(
			esc_html__( 'First select static page in homepage setting for front page.Below given edit button is to customize Home Page. Just click on the edit option, add whatever elements you want to include in the homepage, save the changes and you are good to go.','vw-hospital-lite' ),
		),
		'section' => 'vw_hospital_lite_content_section',
		'button_url'  => admin_url( 'post.php?post='.$homepage.'&action=edit'),
		'button_text' => esc_html__( 'Edit', 'vw-hospital-lite' ),
	) ) );

	// Footer
	$wp_customize->add_section('vw_hospital_lite_footer_section',array(
		'title'	=> __('Copyright','vw-hospital-lite'),
		'description'	=> __('Add some text for footer like copyright etc.','vw-hospital-lite'),
		'priority'	=> null,
		'panel' => 'vw_hospital_lite_panel_id',
	));
	
	$wp_customize->add_setting('vw_hospital_lite_footer_copy',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field',
	));
	
	$wp_customize->add_control('vw_hospital_lite_footer_copy',array(
		'label'	=> __('Copyright Text','vw-hospital-lite'),
		'section'	=> 'vw_hospital_lite_footer_section',
		'type'		=> 'text'
	));

	$wp_customize->add_setting( 'vw_hospital_lite_hide_show_scroll',array(
    	'default' => 1,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'vw_hospital_lite_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Hospital_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'vw_hospital_lite_hide_show_scroll',array(
      	'label' => esc_html__( 'Show / Hide Scroll To Top','vw-hospital-lite' ),
      	'section' => 'vw_hospital_lite_footer_section'
    )));

	$wp_customize->add_setting('vw_hospital_lite_scroll_top_alignment',array(
        'default' => __('Right','vw-hospital-lite'),
        'sanitize_callback' => 'vw_hospital_lite_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Hospital_Lite_Image_Radio_Control($wp_customize, 'vw_hospital_lite_scroll_top_alignment', array(
        'type' => 'select',
        'label' => __('Scroll To Top','vw-hospital-lite'),
        'section' => 'vw_hospital_lite_footer_section',
        'settings' => 'vw_hospital_lite_scroll_top_alignment',
        'choices' => array(
            'Left' => get_template_directory_uri().'/images/layout1.png',
            'Center' => get_template_directory_uri().'/images/layout2.png',
            'Right' => get_template_directory_uri().'/images/layout3.png'
    ))));

	/** home page setions end here**/
	
}
add_action( 'customize_register', 'vw_hospital_lite_customize_register' );

load_template( trailingslashit( get_template_directory() ) . '/inc/logo-resizer.php' );
/**
 * Singleton class for handling the theme's customizer integration.
 *
 * @since  1.0.0
 * @access public
 */
final class VW_Hospital_Lite_Customize {

	/**
	 * Returns the instance.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return object
	 */
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	/**
	 * Constructor method.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function __construct() {}

	/**
	 * Sets up initial actions.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}

	/**
	 * Sets up the customizer sections.
	 *
	 * @since  1.0.0
	 * @access public
	 * @param  object  $manager
	 * @return void
	 */
	public function sections( $manager ) {

		// Load custom sections.
		load_template( trailingslashit( get_template_directory() ) . '/inc/section-pro.php' );

		// Register custom section types.
		$manager->register_section_type( 'VW_Hospital_Lite_Customize_Section_Pro' );

		// Register sections.
		$manager->add_section(new VW_Hospital_Lite_Customize_Section_Pro($manager,'example_1',array(
			'priority'	=> 1,
			'title'    => esc_html__( 'VW Hospital Pro', 'vw-hospital-lite' ),
			'pro_text' => esc_html__( 'Upgrade Pro','vw-hospital-lite' ),
			'pro_url'  => esc_url('https://www.vwthemes.com/premium/hospital-wordpress-theme/')
		)));

		// Register sections.
		$manager->add_section(new VW_Hospital_Lite_Customize_Section_Pro($manager,'example_2',array(
			'priority'   => 1,
			'title'    => esc_html__( 'Documentation', 'vw-hospital-lite' ),
			'pro_text' => esc_html__( 'Docs', 'vw-hospital-lite' ),
			'pro_url'  => esc_url( 'themes.php?page=vw_hospital_lite_guide' )
		)));
	}

	/**
	 * Loads theme customizer CSS.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function enqueue_control_scripts() {

		wp_enqueue_script( 'vw-hospital-lite-customize-controls', trailingslashit( get_template_directory_uri() ) . '/js/customize-controls.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'vw-hospital-lite-customize-controls', trailingslashit( get_template_directory_uri() ) . '/css/customize-controls.css' );
	}
}

// Doing this customizer thang!
VW_Hospital_Lite_Customize::get_instance();